//
//  YHAboutUsViewController.swift
//  galaxy
//
//  Created by edy on 2024/1/6.
//  Copyright © 2024 www.davidhuang.com. All rights reserved.
//

import UIKit
import DeviceKit

class YHAboutUsViewController: YHBaseViewController {

    lazy var collectView = {
       
        // 设置布局方向
        let flowLayout = UICollectionViewFlowLayout()
        let margin = 18.0
        let gap = 12.0
        let itemWidth = floor((KScreenWidth-2*margin-gap)/2.0)
        flowLayout.itemSize = CGSize(width: itemWidth, height: itemWidth)
        flowLayout.minimumInteritemSpacing = 12.0
        flowLayout.scrollDirection = .vertical
        
        let collectinoView = UICollectionView(frame: .zero, collectionViewLayout: flowLayout)
        collectinoView.contentInset = UIEdgeInsets(top: 0, left: margin, bottom: 0, right: margin)
        collectinoView.backgroundColor = UIColor.white
        collectinoView.register(YHAboutUsAdvantageCell.self, forCellWithReuseIdentifier:YHAboutUsAdvantageCell.cellReuseIdentifier)
        collectinoView.delegate = self
        collectinoView.dataSource = self
        return collectinoView
    }()
    
    lazy var aboutLabel = {
            var label = UILabel()
            label.text = "关于银河"
            label.textColor = UIColor(hexString:"#222222")
            label.textAlignment = NSTextAlignment.left
            label.font = UIFont.systemFont(ofSize: 20)
            return label
    }()
    
    lazy var detailLabel = {
            var label = UILabel()
            label.text = "银河集团专注海外服务17年，总部设立在深圳，现已分别在北京、上海、广州等地建立分公司，立足于香港身份规划服务，业务逐步多元化发展。"
            label.numberOfLines = 0
            label.textColor = UIColor(hexString:"#888F98")
            label.textAlignment = NSTextAlignment.left
            label.font = UIFont.systemFont(ofSize: 14)
           return label
    }()
    
    lazy var advantageLabel = {
        var label = UILabel()
        label.text = "四大优势"
        label.textColor = UIColor(hexString:"#222222")
        label.textAlignment = .center
        label.font = UIFont.systemFont(ofSize: 15)
        return label
    }()
    
    lazy var advantageLeftImgView = {
            let arrowImgView = UIImageView(image: UIImage(named: "about_advantage_left"))
            return arrowImgView
    }()
    
    lazy var advantageRightImgView = {
            let arrowImgView = UIImageView(image: UIImage(named: "about_advantage_right"))
            return arrowImgView
    }()
    
    
    
    override func viewDidLoad() {
        super.viewDidLoad()
        setupUI()
    }
    
    func setupUI() {
        
        self.title = "关于我们"
        view.backgroundColor = .white
        
        view.addSubview(collectView)
        view.addSubview(aboutLabel)
        view.addSubview(detailLabel)
        view.addSubview(advantageLabel)
        view.addSubview(advantageLeftImgView)
        view.addSubview(advantageRightImgView)

        aboutLabel.snp.makeConstraints { make in
            make.left.equalTo(view).offset(18)
            make.right.equalTo(view).offset(-18)
            make.top.equalTo(view).offset(k_Height_NavigationtBarAndStatuBar+18)
        }
        
        detailLabel.snp.makeConstraints { make in
            make.left.equalTo(view).offset(18)
            make.right.equalTo(view).offset(-18)
            make.top.equalTo(aboutLabel.snp.bottom).offset(18)
        }
        
        advantageLabel.snp.makeConstraints { make in
            make.centerX.equalTo(view)
            make.height.equalTo(40)
            make.top.equalTo(detailLabel.snp.bottom).offset(48)
        }
        
        advantageLeftImgView.snp.makeConstraints { make in
            make.size.equalTo(CGSize(width: 30, height: 3))
            make.centerY.equalTo(advantageLabel)
            make.right.equalTo(advantageLabel.snp.left).offset(-12)
        }
        
        advantageRightImgView.snp.makeConstraints { make in
            make.size.equalTo(CGSize(width: 30, height: 3))
            make.centerY.equalTo(advantageLabel)
            make.left.equalTo(advantageLabel.snp.right).offset(12)
        }
        
        collectView.snp.makeConstraints { make in
            make.left.right.bottom.equalTo(view)
            make.top.equalTo(advantageLabel.snp.bottom).offset(22)
        }

    }
}

extension YHAboutUsViewController: UICollectionViewDelegateFlowLayout, UICollectionViewDelegate, UICollectionViewDataSource {
    
    func collectionView(_ collectionView: UICollectionView, numberOfItemsInSection section: Int) -> Int {
        return 4
    }
        
    func collectionView(_ collectionView: UICollectionView, cellForItemAt indexPath: IndexPath) -> UICollectionViewCell {
        let cell = collectionView.dequeueReusableCell(withReuseIdentifier: YHAboutUsAdvantageCell.cellReuseIdentifier, for: indexPath) as! YHAboutUsAdvantageCell
            
        return cell

    }
        
    func collectionView(collectionView: UICollectionView, didSelectItemAtIndexPath indexPath: NSIndexPath) {
        print("index is \(indexPath.row)")
    }
}
